@@ -11,7 +11,7 @@ auto_AUTHNumber.py - The core part of the Author Number library.
 
 Author: Matt Belfast Brown 
 Creat Date:2021-05-30
-Version:1.0.0.0004-formal edition
+Version:1.0.1-formal edition
 
 
 THIS PROGRAM IS FREE FOR EVERYONE,IS LICENSED UNDER GPL-3.0
@@ -41,7 +41,7 @@ def make_pronouncation(inpt_name):
     surn_name,last_name=an.fun_spli_name(inpt_name)
     surn_pron=get_pronouncation(surn_name)
     last_pron=get_pronouncation(last_name)
-    if last_name =='':
-        last_porn=[['a']]
+    if last_pron ==[]:
+        last_pron=[['a']]
     
     return [surn_pron,last_pron,surn_name,last_name]
\ No newline at end of file
